Learn R Programming

SNPchip (version 2.18.0)

xypanel: A panel function for plotting copy number versus physical position

Description

A panel function for xyplot for plotting copy number versus physical position.

Usage

xypanel(x, y, gt, is.snp, range, col.hom = "grey20", fill.hom = "lightblue", col.het = "grey20", fill.het = "salmon", col.np = "grey20", fill.np = "grey60", show.state=TRUE, state.cex=1, col.state="blue", ..., subscripts)

Arguments

x
Physical position in megabases.
y
Copy number estimates.
gt
Genotype calls.
is.snp
Logical. Whether the marker is polymorphic.
range
A RangedData or IRanges object. Note that we expect the units returned by start and end to be basepairs.
col.hom
A specification for the color of plotting symbols for homozygous genotypes.
fill.hom
A specification for the fill color of plotting symbols for homozygous genotypes.
col.het
A specification for the color of plotting symbols for heterozygous genotypes.
fill.het
A specification for the fill color of plotting symbols for heterozygous genotypes.
col.np
A specification for the color of plotting symbols for nonpolymorphic markers.
fill.np
A specification for the fill color of plotting symbols for nonpolymorphic genotypes.
show.state
Logical. Whether to display the predicted state in each panel.
state.cex
Numeric. cex for state label. Ignored if show.state is FALSE.
col.state
Character. color for state label. Ignored if show.state is FALSE.
...
Additional arguments passed to lattice functions xyplot, lpoints, and lrect.
subscripts
See the panel functions in lattice for more information.

Details

The order of plotting is (1) nonpolymorphic markers, (2), homozygous SNPs, and (3) heterozygous SNPs. Stretches of homozygosity should appear as blue using the default color scheme.

See Also

xyplot

Examples

Run this code
## Not run: 
# 	if(require("crlmm") && require("VanillaICE") && require("IRanges")){
# 		library(oligoClasses)
# 		data(cnSetExample, package="crlmm")
# 		cnSetExample <- chromosomePositionOrder(cnSetExample)
# 		oligoSet <- as(cnSetExample, "oligoSnpSet")
# 		fit2 <- hmm(oligoSet, p.hom=1)
# 		xyplot(cn ~ x | range, data=oligoSet, range=fit2[1:10, ],
# 		       frame=2e6,
# 		       panel=xypanel, cex=0.3, pch=21, border="blue",
# 		       scales=list(x="free"),
# 		       col.hom="lightblue", col.het="salmon", col.np="grey60",
# 		       fill.np="grey60",
# 		       xlab="Mb")
# 		## if xyplot method is masked by lattice, do
# 		##xyplot <- VanillaICE:::xyplot
# 	}
# ## End(Not run)

Run the code above in your browser using DataLab