Learn R Programming

SNPchip (version 2.18.0)

xypanelBaf: Panel function for plotting copy number and B allele frequencies for a genomic interval.

Description

Panel function for plotting copy number and B allele frequencies for a genomic interval.

Usage

xypanelBaf(x, y, gt, baf, is.snp, range, col.hom = "grey20", fill.hom = "lightblue", col.het = "grey20", fill.het = "salmon", col.np = "grey20", fill.np = "grey60", show.state = TRUE, state.cex = 1, col.state = "blue", ..., subscripts)

Arguments

x
physical position in basepairs
y
total copy number (relative or absolute)
gt
Genotypes coded as integers (1=AA, 2=AB, 3=BB). This is optional. If provided one can color code the plotting symbols by the genotype.
baf
B allele frequencies.
is.snp
Logical. Indicator of whether the marker hybridized to a known SNP or a nonpolymorphic region of the genome.
range
A RangedDataCNV-derived object indicating the genomic interval to plot.
col.hom
Color to use for homozygous genotypes.
fill.hom
Fill color to use for homozygous genotypes.
col.het
Color to use for heterozygous genotypes.
fill.het
Fill color to use for heterozygous genotypes.
col.np
Color to use for nonpolymorphic markers
fill.np
Fill color for nonpolymorphic markers.
show.state
Logical indicating whether to display the copy number state for a RangedDataHMM object.
state.cex
Size of the font for displaying the HMM state. Ignored if show.state is FALSE.
col.state
Color for displaying the state.
...
Additional arguments passed to panel.xyplot.
subscripts
See panel.xyplot

Details

Function for plotting B allele frequencing and copy number on a trellis display. Intended to be passed to the panel argument of the function xyplotLrrBaf and should not be called directly by the user.

See Also

xyplotLrrBaf